@@ -3,5 +3,5 @@
 
 def __init__(hub):
     hub.metadata.gcp.cloudkms.projects.locations.PATH = (
-        "projects/{project}/locations/{location}"
+        "projects/{project_id}/locations/{location_id}"
     )
