@@ -215,73 +215,46 @@ async def present(
         "comment": [],
     }
 
-    create_if_missing = False
-    if not resource_id:
-        if project_id and location_id and key_ring_id and crypto_key_id:
-            resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-                "cloudkms.projects.locations.key_rings.crypto_keys",
-                {
-                    "project_id": project_id,
-                    "location_id": location_id,
-                    "key_ring_id": key_ring_id,
-                    "crypto_key_id": crypto_key_id,
-                },
-            )
-            create_if_missing = True
-        else:
-            result["result"] = False
-            result["comment"].append(
-                "When creating new resource crypto_key_id, project_id, location_id and key_ring_id parameters are required!"
-            )
-            return result
-    else:
-        els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-            "cloudkms.projects.locations.key_rings.crypto_keys", resource_id
-        )
-        if project_id and location_id and key_ring_id and crypto_key_id:
-            if (
-                els.get("project_id") != project_id
-                or els.get("location_id") != location_id
-                or els.get("key_ring_id") != key_ring_id
-                or els.get("crypto_key_id") != crypto_key_id
-            ):
-                result["result"] = False
-                result["comment"].append(
-                    hub.tool.gcp.comment_utils.non_updatable_properties_comment(
-                        "gcp.cloudkms.crypto_key",
-                        resource_id,
-                        ["project_id", "location_id", "key_ring_id", "crypto_key_id"],
-                    )
-                )
-                return result
-        else:
-            project_id = els.get("project_id")
-            location_id = els.get("location_id")
-            key_ring_id = els.get("key_ring_id")
-            crypto_key_id = els.get("crypto_key_id")
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
 
-    is_create = False
     if resource_id:
         old_get_ret = await hub.exec.gcp.cloudkms.crypto_key.get(
             ctx, resource_id=resource_id
         )
-        if not old_get_ret["result"] or not old_get_ret["ret"]:
-            if not create_if_missing:
-                result["result"] = False
-                result["comment"] += old_get_ret["comment"]
-                return result
-            is_create = True
-        else:
-            result["old_state"] = {
-                "name": name,
+
+        if not old_get_ret["result"] or (
+            not old_get_ret["ret"] and get_resource_only_with_resource_id
+        ):
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
+            return result
+
+        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+    elif not get_resource_only_with_resource_id:
+        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "cloudkms.projects.locations.key_rings.crypto_keys",
+            {
                 "project_id": project_id,
                 "location_id": location_id,
                 "key_ring_id": key_ring_id,
                 "crypto_key_id": crypto_key_id,
-                **copy.copy(old_get_ret["ret"]),
-            }
+            },
+        )
+        old_get_ret = await hub.exec.gcp.cloudkms.crypto_key.get(
+            ctx, resource_id=resource_id
+        )
 
-    if is_create:
+        if not old_get_ret["result"]:
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
+            return result
+
+        if old_get_ret["ret"]:
+            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+
+    if not result["old_state"]:
         resource_body = {
             "purpose": purpose,
             "next_rotation_time": next_rotation_time,
@@ -304,11 +277,117 @@ async def present(
 
     resource_body = {k: v for (k, v) in resource_body.items() if v is not None}
 
-    if ctx["test"]:
-        if is_create:
+    if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
+        update_mask = hub.tool.gcp.cloudkms.patch.calc_update_mask(
+            resource_body, result["old_state"]
+        )
+        if (
+            primary
+            and primary.get("name")
+            and primary["name"]
+            != (result["old_state"].get("primary") or {}).get("name")
+        ):
+            update_primary_version = True
+        else:
+            update_primary_version = False
+
+        if ctx["test"]:
+            if update_mask or update_primary_version:
+                result["new_state"] = {**deepcopy(result["old_state"]), **resource_body}
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.would_update_comment(
+                        "gcp.cloudkms.crypto_key", resource_id
+                    )
+                )
+            else:
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.up_to_date_comment(
+                        "gcp.cloudkms.crypto_key", resource_id
+                    )
+                )
+            return result
+
+        els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
+            "cloudkms.projects.locations.key_rings.crypto_keys", resource_id
+        )
+        if (
+            els.get("project_id") != project_id
+            or els.get("location_id") != location_id
+            or els.get("key_ring_id") != key_ring_id
+            or els.get("crypto_key_id") != crypto_key_id
+        ):
+            result["result"] = False
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.non_updatable_properties_comment(
+                    "gcp.cloudkms.crypto_key",
+                    resource_id,
+                    ["project_id", "location_id", "key_ring_id", "crypto_key_id"],
+                )
+            )
+            return result
+
+        if update_mask:
+            update_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.patch(
+                ctx, name_=resource_id, updateMask=update_mask, body=resource_body
+            )
+            if not update_ret["result"]:
+                result["result"] = False
+                result["comment"] += update_ret["comment"]
+                return result
+
+            result["new_state"] = {
+                "name": name,
+                "project_id": project_id,
+                "location_id": location_id,
+                "key_ring_id": key_ring_id,
+                "crypto_key_id": crypto_key_id,
+                **copy.copy(update_ret["ret"]),
+            }
+
+        if update_primary_version:
+            els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
+                "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+                primary["name"],
+            )
+            update_version_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.updatePrimaryVersion(
+                ctx,
+                name_=resource_id,
+                body={"cryptoKeyVersionId": els["crypto_key_version_id"]},
+            )
+            if not update_version_ret["result"]:
+                result["result"] = False
+                result["comment"] += update_version_ret["comment"]
+                return result
+
+            result["new_state"] = {
+                "name": name,
+                "project_id": project_id,
+                "location_id": location_id,
+                "key_ring_id": key_ring_id,
+                "crypto_key_id": crypto_key_id,
+                "primary": copy.copy(update_version_ret["ret"]["primary"]),
+            }
+
+        if update_mask or update_primary_version:
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.update_comment(
+                    "gcp.cloudkms.crypto_key", resource_id
+                )
+            )
+        else:
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.up_to_date_comment(
+                    "gcp.cloudkms.crypto_key", resource_id
+                )
+            )
+        return result
+
+    else:
+        if ctx["test"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
-                    "gcp.cloudkms.crypto_key", resource_id
+                    "gcp.cloudkms.crypto_key", name
                 )
             )
             result["new_state"] = {
@@ -320,26 +399,8 @@ async def present(
                 "crypto_key_id": crypto_key_id,
                 **resource_body,
             }
-        else:
-            result["new_state"] = {**deepcopy(result["old_state"]), **resource_body}
-            update_mask = hub.tool.gcp.cloudkms.patch.calc_update_mask(
-                resource_body, result["old_state"]
-            )
-            if update_mask:
-                result["comment"].append(
-                    hub.tool.gcp.comment_utils.would_update_comment(
-                        "gcp.cloudkms.crypto_key", resource_id
-                    )
-                )
-            else:
-                result["comment"].append(
-                    hub.tool.gcp.comment_utils.already_exists_comment(
-                        "gcp.cloudkms.crypto_key", resource_id
-                    )
-                )
-        return result
+            return result
 
-    if is_create:
         create_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.create(
             ctx,
             parent=hub.tool.gcp.resource_prop_utils.construct_resource_id(
@@ -371,67 +432,8 @@ async def present(
             "crypto_key_id": crypto_key_id,
             **copy.copy(create_ret["ret"]),
         }
-    else:
-        update_mask = hub.tool.gcp.cloudkms.patch.calc_update_mask(
-            resource_body, result["old_state"]
-        )
-        if update_mask:
-            update_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.patch(
-                ctx, name_=resource_id, updateMask=update_mask, body=resource_body
-            )
-            if not update_ret["result"]:
-                result["result"] = False
-                result["comment"] += update_ret["comment"]
-                return result
-
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.update_comment(
-                    "gcp.cloudkms.crypto_key", resource_id
-                )
-            )
-            result["new_state"] = {
-                "name": name,
-                "project_id": project_id,
-                "location_id": location_id,
-                "key_ring_id": key_ring_id,
-                "crypto_key_id": crypto_key_id,
-                **copy.copy(update_ret["ret"]),
-            }
-
-        else:
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
-                    "gcp.cloudkms.crypto_key", resource_id
-                )
-            )
-            result["new_state"] = deepcopy(result["old_state"])
-
-    if primary and primary.get("name"):
-        if primary["name"] != (result["old_state"].get("primary") or {}).get("name"):
-            els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-                "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
-                primary["name"],
-            )
-            update_version_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.updatePrimaryVersion(
-                ctx,
-                name_=resource_id,
-                body={"cryptoKeyVersionId": els["crypto_key_version_id"]},
-            )
-            if not update_version_ret["result"]:
-                result["result"] = False
-                result["comment"] += update_version_ret["comment"]
-                return result
-
-            result["new_state"]["primary"] = copy.copy(
-                update_version_ret["ret"]["primary"]
-            )
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.update_comment(
-                    "gcp.cloudkms.crypto_key", resource_id
-                )
-            )
-
-    return result
+        result["old_state"] = {}
+        return result
 
 
 async def absent(hub, ctx, name: str) -> Dict[str, Any]:
