@@ -1,4 +1,5 @@
 """State module for managing Cloud Key Management Service key rings."""
+import copy
 from typing import Any
 from typing import Dict
 
@@ -54,62 +55,73 @@ async def present(
         "comment": [],
     }
 
-    create_if_missing = False
-    if not resource_id:
-        if project_id and location_id and key_ring_id:
-            resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-                "cloudkms.projects.locations.key_rings",
-                {
-                    "project_id": project_id,
-                    "location_id": location_id,
-                    "key_ring_id": key_ring_id,
-                },
-            )
-            create_if_missing = True
-        else:
-            result["result"] = False
-            result["comment"].append(
-                "When creating new resource key_ring_id, project_id and location_id parameters are required!"
-            )
-            return result
-
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
     if resource_id:
         old_get_ret = await hub.exec.gcp.cloudkms.key_ring.get(
             ctx, resource_id=resource_id
         )
-        if not old_get_ret["result"] or not old_get_ret["ret"]:
-            if not create_if_missing:
-                result["result"] = False
-                result["comment"] += old_get_ret["comment"]
-                return result
-        else:
-            els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-                "cloudkms.projects.locations.key_rings", resource_id
-            )
-            if (
-                els.get("project_id") != project_id
-                or els.get("location_id") != location_id
-                or els.get("key_ring_id") != key_ring_id
-            ):
-                result["result"] = False
-                result["comment"].append(
-                    hub.tool.gcp.comment_utils.non_updatable_properties_comment(
-                        "gcp.cloudkms.key_ring",
-                        key_ring_id,
-                        ["project_id", "location_id", "key_ring_id"],
-                    )
-                )
-                return result
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
-                    "gcp.cloudkms.key_ring", key_ring_id
-                )
-            )
-            result["old_state"] = old_get_ret["ret"]
-            result["new_state"] = old_get_ret["ret"]
-            result["new_state"]["name"] = name
+
+        if not old_get_ret["result"] or (
+            not old_get_ret["ret"] and get_resource_only_with_resource_id
+        ):
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
             return result
 
+        result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+    elif not get_resource_only_with_resource_id:
+        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+            "cloudkms.projects.locations.key_rings",
+            {
+                "project_id": project_id,
+                "location_id": location_id,
+                "key_ring_id": key_ring_id,
+            },
+        )
+        old_get_ret = await hub.exec.gcp.cloudkms.key_ring.get(
+            ctx, resource_id=resource_id
+        )
+
+        if not old_get_ret["result"]:
+            result["result"] = False
+            result["comment"] += old_get_ret["comment"]
+            return result
+
+        if old_get_ret["ret"]:
+            result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
+
+    if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
+
+        els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
+            "cloudkms.projects.locations.key_rings", resource_id
+        )
+        if (
+            els.get("project_id") != project_id
+            or els.get("location_id") != location_id
+            or els.get("key_ring_id") != key_ring_id
+        ):
+            result["result"] = False
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.non_updatable_properties_comment(
+                    "gcp.cloudkms.key_ring",
+                    key_ring_id,
+                    ["project_id", "location_id", "key_ring_id"],
+                )
+            )
+            return result
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.already_exists_comment(
+                "gcp.cloudkms.key_ring", key_ring_id
+            )
+        )
+        result["old_state"] = old_get_ret["ret"]
+        result["new_state"] = old_get_ret["ret"]
+        result["new_state"]["name"] = name
+        return result
+
     if ctx["test"]:
         plan_state = {"resource_id": resource_id, "name": name}
         result["comment"].append(
