@@ -642,122 +642,31 @@ async def present(
 async def absent(
     hub,
     ctx,
-    name: str,
+    name: str = None,
+    project: str = None,
     resource_id: str = None,
     request_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified persistent disk.
-
-    Deleting a disk removes its data permanently and is irreversible.
-    However, deleting a disk does not delete any snapshots previously made from the disk.
-    You must separately delete snapshots.
+    r"""Deletes the resource.
 
     Args:
-        name(str):
+        name(str, Optional):
             An Idem name of the resource.
 
-        resource_id(str, Optional):
-            An identifier of the resource in the provider.
-            Defaults to None.
+        project(str, Optional):
+            Project ID for this request.
 
         request_id(str, Optional):
-            An optional request ID to identify requests.
-            Specify a unique request ID so that if you must retry your request,
-            the server will know to ignore the request if it has already been completed.
-            For example, consider a situation where you make an initial request and the request times out.
-            If you make the request again with the same request ID,
-            the server can check if original operation with the same request ID was received, and if so,
-            will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
-            The request ID must be a valid UUID with the exception that zero UUID is not supported
-            ( 00000000-0000-0000-0000-000000000000).
-            Defaults to None.
+            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
+
+        resource_id(str, Optional):
+            An identifier of the resource in the provider. Defaults to None.
 
     Returns:
         Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            resource_is_absent:
-              gcp.compute.disk.absent:
-                - resource_id: resource_id
     """
-    result = {
-        "result": True,
-        "old_state": ctx.get("old_state"),
-        "new_state": None,
-        "name": name,
-        "comment": [],
-    }
-
-    if not resource_id and not hub.OPT.idem.get(
-        "get_resource_only_with_resource_id", False
-    ):
-        resource_id = (ctx.get("old_state") or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.disk", {**locals(), "disk": name}
-        )
-
-    if not resource_id:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment("gcp.compute.disk", name)
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        get_ret = await hub.exec.gcp.compute.disk.get(ctx, resource_id=resource_id)
-
-        if not get_ret["result"]:
-            result["result"] = False
-            result["comment"] += get_ret["comment"]
-            return result
-
-        if not get_ret["ret"]:
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.already_absent_comment(
-                    "gcp.compute.disk", name
-                )
-            )
-            return result
-
-        result["old_state"] = get_ret["ret"]
-
-    if ctx["test"]:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment("gcp.compute.disk", name)
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        # First iteration; invoke disk's delete()
-        delete_ret = await hub.exec.gcp_api.client.compute.disk.delete(
-            ctx, resource_id=resource_id
-        )
-        if delete_ret["ret"]:
-            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
-                result["result"] = False
-                result["comment"] += delete_ret["comment"]
-                result[
-                    "rerun_data"
-                ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    delete_ret["ret"].get("selfLink"), "compute.zone_operation"
-                )
-                return result
-    else:
-        # delete() has been called on some previous iteration
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.disk"
-        )
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-    result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment("gcp.compute.disk", name)
-    )
-    return result
+    # the method is handled via the recursive_contracts->call_absent
+    raise NotImplementedError
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
