@@ -19,8 +19,6 @@ async def present(
     ctx,
     name: str,
     project: str = None,
-    request_id: str = None,
-    id_: str = None,
     target_tags: List[str] = None,
     source_service_accounts: List[str] = None,
     denied: List[
@@ -51,15 +49,12 @@ async def present(
         ]
     ] = None,
     disabled: bool = None,
-    self_link: str = None,
     network: str = None,
     priority: int = None,
     log_config: Dict[str, Any] = None,
     target_service_accounts: List[str] = None,
-    creation_timestamp: str = None,
     source_tags: List[str] = None,
     source_ranges: List[str] = None,
-    kind: str = "compute#firewall",
     resource_id: str = None,
 ) -> Dict[str, Any]:
     r"""Creates or updates a firewall rule in the specified project using the data included in the request.
@@ -67,8 +62,6 @@ async def present(
     Args:
         name(str): An Idem name of the resource.
         project(str, Optional): Project ID for this request.
-        id_(str, Optional):
-            [Output Only] The unique identifier for the resource. This identifier is defined by the server. Defaults to None.
         target_tags(List[str], Optional):
             A list of tags that controls which instances the firewall rule applies to. If targetTags are specified,
             then the firewall rule applies only to instances in the VPC network that have one of those tags. If no
@@ -82,7 +75,7 @@ async def present(
             instance with service account listed in sourceServiceAccount. The connection does not need to match both
             fields for the firewall to apply. sourceServiceAccounts cannot be used at the same time as sourceTags or
             targetTags. Defaults to None.
-        denied(list[Dict[str, Dict[str, Any]]], optional):
+        denied(list[Dict[str, Dict[str, Any]]], Optional):
             The list of DENY rules specified by this firewall. Each rule specifies a protocol and port-range tuple that
             describes a denied connection. Defaults to None.
             * IPProtocol (str, Optional): The IP protocol to which this rule applies. The protocol type is required when
@@ -113,8 +106,6 @@ async def present(
         disabled(bool, Optional):
             Denotes whether the firewall rule is disabled. When set to true, the firewall rule is not enforced and the
             network behaves as if it did not exist. If this is unspecified, the firewall rule will be enabled. Defaults to None.
-        self_link(str, Optional):
-            [Output Only] Server-defined URL for the resource. Defaults to None.
         network(str, Optional):
             URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the
             default network is used: global/networks/default If you choose to specify this field, you can specify the
@@ -136,8 +127,6 @@ async def present(
             connections as specified in allowed[]. targetServiceAccounts cannot be used at the same time as targetTags
             or sourceTags. If neither targetServiceAccounts nor targetTags are specified, the firewall rule applies to
             all instances on the specified network. Defaults to None.
-        creation_timestamp(str, Optional):
-            [Output Only] Creation timestamp in RFC3339 text format. Defaults to None.
         source_tags(List[str], Optional):
             If source tags are specified, the firewall rule applies only to traffic with source IPs that match the
             primary network interfaces of VM instances that have the tag and are in the same VPC network. Source tags
@@ -152,8 +141,6 @@ async def present(
             be set. If both fields are set, the rule applies to traffic that has a source IP address within sourceRanges
             OR a source IP from a resource with a matching tag listed in the sourceTags field. The connection does not
             need to match both fields for the rule to apply. Both IPv4 and IPv6 are supported. Defaults to None.
-        kind(str, Optional):
-            [Output Only] Type of the resource. Always compute#firewall for firewall rules. Defaults to "compute#firewall".
         resource_id(str, Optional):
             An identifier of the resource in the provider. Defaults to None.
 
@@ -255,7 +242,6 @@ async def present(
             result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
 
     resource_body = {
-        "creation_timestamp": creation_timestamp,
         "priority": priority,
         "log_config": log_config,
         "direction": direction,
@@ -371,119 +357,31 @@ async def present(
 async def absent(
     hub,
     ctx,
-    name: str,
+    name: str = None,
     project: str = None,
-    request_id: str = None,
     resource_id: str = None,
+    request_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified firewall.
+    r"""Deletes the resource.
 
     Args:
-        name(str): Name of the firewall rule to return.
-        project(str, Optional): Project ID for this request.
-        request_id(str, Optional): An optional request ID to identify requests. Specify a unique request ID so that if
-            you must retry your request, the server will know to ignore the request if it has already been completed.
-            For example, consider a situation where you make an initial request and the request times out. If you make
-            the request again with the same request ID, the server can check if original operation with the same request
-            ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating
-            duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not
-            supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
+        name(str, Optional):
+            An Idem name of the resource.
+
+        project(str, Optional):
+            Project ID for this request.
+
+        request_id(str, Optional):
+            An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
+
         resource_id(str, Optional):
             An identifier of the resource in the provider. Defaults to None.
 
     Returns:
         Dict[str, Any]
-
-    Examples:
-
-        .. code-block:: sls
-
-            resource_is_absent:
-              gcp.compute.firewall.absent:
-                - name: value
-                - project: value
-                - firewall: value
     """
-
-    result = {
-        "result": True,
-        "old_state": None,
-        "new_state": None,
-        "name": name,
-        "comment": [],
-    }
-
-    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
-    if not resource_id and not hub.OPT.idem.get(
-        "get_resource_only_with_resource_id", False
-    ):
-        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.firewall", {**locals(), "firewall": name}
-        )
-
-    if not resource_id:
-        result["comment"].append(
-            hub.tool.aws.comment_utils.already_absent_comment(
-                "gcp.compute.firewall", name
-            )
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        get_ret = await hub.exec.gcp.compute.firewall.get(ctx, resource_id=resource_id)
-
-        if not get_ret["result"]:
-            result["result"] = False
-            result["comment"] += get_ret["comment"]
-            return result
-
-        if not get_ret["ret"]:
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.already_absent_comment(
-                    "gcp.compute.firewall", name
-                )
-            )
-            return result
-
-        result["old_state"] = get_ret["ret"]
-
-    if ctx["test"]:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment(
-                "gcp.compute.firewall", name
-            )
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        # First iteration; invoke firewall's delete()
-        delete_ret = await hub.exec.gcp_api.client.compute.firewall.delete(
-            ctx, resource_id=resource_id, request_id=request_id
-        )
-        if hub.tool.gcp.operation_utils.is_operation(delete_ret.get("ret")):
-            result["result"] = False
-            result["comment"] += delete_ret["comment"]
-            result[
-                "rerun_data"
-            ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                delete_ret["ret"].get("selfLink"), "compute.global_operation"
-            )
-            return result
-    else:
-        # delete() has been called on some previous iteration
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.firewall"
-        )
-        if not handle_operation_ret["result"]:
-            result["result"] = False
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-    result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment("gcp.compute.firewall", name)
-    )
-    return result
+    # the method is handled via the recursive_contracts->call_absent
+    raise NotImplementedError
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
