@@ -119,10 +119,10 @@ async def present(
     Examples:
         .. code-block:: sls
 
-        example_resource_name:
-            gcp.compute.machine_image.present:
-              - project: project-name
-              - source_instance: https://www.googleapis.com/compute/v1/projects/project-name/zones/zone-name/instances/instance-name
+            example_resource_name:
+              gcp.compute.machine_image.present:
+                - project: project-name
+                - source_instance: https://www.googleapis.com/compute/v1/projects/project-name/zones/zone-name/instances/instance-name
     """
     result = {
         "result": True,
@@ -134,57 +134,12 @@ async def present(
 
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
-    # Get the resource_id from ESM
-    if not resource_id:
-        resource_id = (ctx.get("old_state") or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.machine_image", {**locals(), "machineImage": name}
-        )
-    old = None
-
-    # TODO: Handle operation result state
-    if ctx.get("rerun_data"):
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.machine_image"
+    if ctx.get("wrapper_result"):
+        result["old_state"] = copy.deepcopy(
+            copy.copy(ctx.get("wrapper_result").get("old_state", None))
         )
 
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    if resource_id:
-        old_get_ret = await hub.exec.gcp_api.client.compute.machine_image.get(
-            ctx, resource_id=resource_id
-        )
-
-        if not old_get_ret["result"]:
-            # error other than non-existing resource
-            result["result"] = False
-            result["comment"] += old_get_ret["comment"]
-            return result
-
-        if old_get_ret["ret"]:
-            # resource already exists
-
-            # copy.copy(old_get_ret['ret']) is needed to convert any objects of type NamespaceDict to dict
-            # in old_get_ret['ret']. This is done so that comparisons with the plan_state which has
-            # objects of type dict works properly
-            old = copy.deepcopy(copy.copy(old_get_ret["ret"]))
-            result["old_state"] = old
-
-            # If rerun_data is set at this point this means that there has been a completed create or update operation
-            # so there is no need to run the code for create or update below again and we stop here
-            if ctx.get("rerun_data"):
-                result["new_state"] = result["old_state"]
-                return result
-
-    # TODO: Check if body contains the same parameters as old
-    # to be autogenerated by pop-create based on insert/update props in properties.yaml
-    resource_body = {
+    request_body = {
         "storage_locations": storage_locations,
         "guest_flush": guest_flush,
         "source_instance": source_instance,
@@ -195,36 +150,44 @@ async def present(
         "source_disk_encryption_keys": source_disk_encryption_keys,
     }
 
-    # TODO: How to handle query params which are not returned in the response body of get
-    plan_state = {
-        # "project": project,
-        # "predefined_acl": predefined_acl,
-        # "predefined_default_object_acl": predefined_default_object_acl,
-        "resource_id": resource_id,
-        **resource_body,
-    }
-
-    plan_state = {k: v for (k, v) in plan_state.items() if v is not None}
     operation = None
-    if old:
+    plan_state = {"resource_id": resource_id, **request_body}
+    plan_state = {k: v for (k, v) in plan_state.items() if v is not None}
+
+    if result["old_state"]:
+        resource_id = result["old_state"].get("resource_id", None)
+
         changes = hub.tool.gcp.utils.compare_states(
-            old, plan_state, "compute.machine_image"
+            result["old_state"], plan_state, "compute.machine_image"
         )
+
         if not changes:
             result["result"] = True
             result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
+                hub.tool.gcp.comment_utils.up_to_date_comment(
                     "gcp.compute.machine_image", name
                 )
             )
-            result["new_state"] = result["old_state"]
+            result["new_state"] = copy.deepcopy(result["old_state"])
             return result
 
-        result["comment"].append(
-            "No-op: There is no update function for gcp.compute.machine_image"
-        )
-
+        if ctx["test"]:
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.would_update_comment(
+                    "gcp.compute.machine_image", name
+                )
+            )
+            result["new_state"] = plan_state
+            return result
+        else:
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.no_resource_update_comment(
+                    "gcp.compute.machine_image"
+                )
+            )
+            return result
     else:
+        # Create machine image
         if ctx["test"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
@@ -232,21 +195,21 @@ async def present(
                 )
             )
             result["new_state"] = plan_state
+            result["new_state"][
+                "resource_id"
+            ] = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+                "compute.machine_image", {**locals(), "machineImage": name}
+            )
             return result
 
-        # Create
         create_ret = await hub.exec.gcp_api.client.compute.machine_image.insert(
-            ctx, project=project, body=resource_body
+            ctx, project=project, body=request_body
         )
         if not create_ret["result"]:
             result["result"] = False
             result["comment"] += create_ret["comment"]
             return result
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.create_comment("gcp.compute.machine_image", name)
-        )
-        result["old_state"] = {}
-        resource_id = create_ret["ret"].get("resource_id")
+
         if hub.tool.gcp.operation_utils.is_operation(create_ret["ret"]):
             operation = create_ret["ret"]
 
@@ -254,136 +217,42 @@ async def present(
         operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
             operation.get("selfLink"), "compute.global_operation"
         )
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, operation_id, "compute.machine_image"
-        )
 
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    # Try getting the resource again
-    # TODO: Reconciliation or waiter loop?
-    # TODO: Check if this can be removed because insert and update may also return the necessary data on success
-    get_ret = await hub.exec.gcp_api.client.compute.machine_image.get(
-        ctx, resource_id=resource_id
-    )
-
-    if not get_ret["result"] and not get_ret["ret"]:
-        result["result"] = False
-        result["comment"] += get_ret["comment"]
+        result["rerun_data"] = {
+            "operation_id": operation_id,
+            "old_state": result["old_state"],
+        }
         return result
 
-    result["new_state"] = get_ret["ret"]
-
-    return result
-
 
 async def absent(
     hub,
     ctx,
-    name: str,
+    name: str = None,
     project: str = None,
     resource_id: str = None,
     request_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified machine image. Deleting a machine image is permanent and cannot be undone.
+    r"""Deletes the resource.
 
     Args:
-        name(str):
+        name(str, Optional):
             An Idem name of the resource.
 
         project(str, Optional):
             Project ID for this request.
 
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
-
         request_id(str, Optional):
             An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
 
+        resource_id(str, Optional):
+            An identifier of the resource in the provider. Defaults to None.
+
     Returns:
         Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            resource_is_absent:
-              gcp.compute.machine_image.absent:
-                - name: value
-                - project: value
-                - machine_image: value
     """
-    result = {
-        "comment": [],
-        "old_state": ctx.get("old_state"),
-        "new_state": None,
-        "name": name,
-        "result": True,
-    }
-
-    project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
-
-    if not resource_id and not hub.OPT.idem.get(
-        "get_resource_only_with_resource_id", False
-    ):
-        resource_id = (ctx.get("old_state") or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.machine_image", {**locals(), "machineImage": name}
-        )
-
-    if ctx.test:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment(
-                "gcp.compute.machine_image", name
-            )
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        # First iteration; invoke machine image's delete()
-        delete_ret = await hub.exec.gcp_api.client.compute.machine_image.delete(
-            ctx, resource_id=resource_id
-        )
-        if delete_ret["ret"]:
-            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
-                result["result"] = False
-                result["comment"] += delete_ret["comment"]
-                result[
-                    "rerun_data"
-                ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    delete_ret["ret"].get("selfLink"), "compute.global_operation"
-                )
-                return result
-
-    else:
-        # delete() has been called on some previous iteration
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.machine_image"
-        )
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    if not resource_id:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment(
-                "gcp.compute.machine_image", name
-            )
-        )
-        return result
-
-    result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment("gcp.compute.machine_image", name)
-    )
-    return result
+    # the method is handled via the recursive_contracts->call_absent
+    raise NotImplementedError
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
