@@ -88,7 +88,7 @@ async def present(
         resource_id(str, Optional):
             An identifier of the resource in the provider. Defaults to None.
 
-        peerings(List[Dict[str, Any]], Optional): [Output Only] A list of network peerings for the resource. Defaults to None.
+        peerings(List[Dict[str, Any]], Optional): A list of network peerings for the resource. Defaults to None.
             * export_custom_routes(bool, Optional):
                 Whether to export the custom routes to peer network. The default value is false.
             * auto_create_routes(bool, Optional):
@@ -354,88 +354,30 @@ async def absent(
     hub,
     ctx,
     name: str = None,
+    project: str = None,
     resource_id: str = None,
     request_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified network.
+    r"""Deletes the resource.
 
     Args:
-        name(str):
+        name(str, Optional):
             An Idem name of the resource.
 
-        resource_id(str, Optional):
-            An identifier of the resource in the provider. Defaults to None.
+        project(str, Optional):
+            Project ID for this request.
 
         request_id(str, Optional):
             An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000). Defaults to None.
 
+        resource_id(str, Optional):
+            An identifier of the resource in the provider. Defaults to None.
+
     Returns:
         Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            my-network:
-              gcp.compute.network.absent:
-                - resource_id: projects/project-name/global/networks/my-network
-
     """
-    result = {
-        "comment": [],
-        "old_state": ctx.get("old_state"),
-        "new_state": None,
-        "name": name,
-        "result": True,
-    }
-
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get("resource_id")
-
-    if ctx.test:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment("gcp.compute.network", name)
-        )
-        return result
-
-    if not ctx.get("rerun_data"):
-        # First iteration; invoke instance's delete()
-        delete_ret = await hub.exec.gcp_api.client.compute.network.delete(
-            ctx, resource_id=resource_id
-        )
-        if delete_ret["ret"]:
-            if hub.tool.gcp.operation_utils.is_operation(delete_ret["ret"]):
-                result["result"] = False
-                result["comment"] += delete_ret["comment"]
-                result[
-                    "rerun_data"
-                ] = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    delete_ret["ret"].get("selfLink"), "compute.global_operation"
-                )
-                return result
-
-    else:
-        # delete() has been called on some previous iteration
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.network"
-        )
-        if not handle_operation_ret["result"]:
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    if not resource_id:
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment(
-                "gcp.compute.network", name
-            )
-        )
-
-    result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment("gcp.compute.network", name)
-    )
-    return result
+    # the method is handled via the recursive_contracts->call_absent
+    raise NotImplementedError
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
