@@ -190,12 +190,30 @@ async def present(
     ) = None,
     metageneration: str = None,
     if_metageneration_match: str = None,
+    acl: List[
+        make_dataclass(
+            "BucketAccessControl",
+            [
+                ("entity", str, field(default=None)),
+                ("role", str, field(default=None)),
+            ],
+        )
+    ] = None,
+    default_object_acl: List[
+        make_dataclass(
+            "ObjectAccessControl",
+            [
+                ("entity", str, field(default=None)),
+                ("role", str, field(default=None)),
+            ],
+        )
+    ] = None,
 ) -> Dict[str, Any]:
     r"""Create or update a storage bucket resource. Changes to the bucket will be readable immediately after writing, but configuration changes may take time to propagate.
 
         Args:
             name(str): An Idem name of the resource.
-            resource_id(str, optional): An identifier of the resource in the provider. Defaults to None.
+            resource_id(str, Optional): An identifier of the resource in the provider. Defaults to None.
             project(str): A valid API project identifier.
             predefined_acl(str, optional): Apply a predefined set of access controls to this bucket. Defaults to None.
             predefined_default_object_acl(str, optional): Apply a predefined set of default object access controls to this bucket. Defaults to None.
@@ -258,6 +276,34 @@ async def present(
                 * not_found_page (str, optional): If the requested object path is missing, and any mainPageSuffix object is missing, if applicable, the service will return the named object from this bucket as the content for a 404 Not Found result.
             metageneration(str, optional): The metadata generation of this bucket. Read-only property
             if_metageneration_match(str, optional): Makes the operation conditional on whether bucket's current metageneration matches the given value. Currently used only when locking retention policy
+            acl(list[Dict[str, Any]], Optional): Access controls on the bucket. Defaults to None.
+                * entity (str, Optional): The entity holding the permission, in one of the following forms:
+                    - user-userId
+                    - user-email
+                    - group-groupId
+                    - group-email
+                    - domain-domain
+                    - project-team-projectId
+                    - allUsers
+                    - allAuthenticatedUsers Examples:
+                    - The user liz@example.com would be user-liz@example.com.
+                    - The group example@googlegroups.com would be group-example@googlegroups.com.
+                    - To refer to all members of the Google Apps for Business domain example.com, the entity would be domain-example.com.
+                * role (str, Optional): The access permission for the entity.
+            default_object_acl(list[Dict[str, Any]], Optional): Default access controls to apply to new objects when no ACL is provided. Defaults to None.
+                * entity (str, Optional): The entity holding the permission, in one of the following forms:
+                    - user-userId
+                    - user-email
+                    - group-groupId
+                    - group-email
+                    - domain-domain
+                    - project-team-projectId
+                    - allUsers
+                    - allAuthenticatedUsers Examples:
+                    - The user liz@example.com would be user-liz@example.com.
+                    - The group example@googlegroups.com would be group-example@googlegroups.com.
+                    - To refer to all members of the Google Apps for Business domain example.com, the entity would be domain-example.com.
+                * role (str, Optional): The access permission for the entity.
     Returns:
         Dict[str, Any]
 
@@ -344,6 +390,8 @@ async def present(
         "versioning": versioning,
         "website": website,
         "metageneration": metageneration,
+        "acl": acl,
+        "default_object_acl": default_object_acl,
     }
 
     plan_state = {
