@@ -16,6 +16,10 @@ def camel(hub, string: str, dromedary: bool = True) -> str:
         return result
 
 
+def is_camel_case(hub, value: str) -> bool:
+    return hub.tool.gcp.case.camel(value) == value
+
+
 # TODO: Write a test to validate corner cases like abcXTZ
 def snake(hub, string: str) -> str:
     """
@@ -32,3 +36,7 @@ def snake(hub, string: str) -> str:
     string = string.replace("__", "_")
 
     return string
+
+
+def is_snake_case(hub, value: str) -> bool:
+    return hub.tool.gcp.case.snake(value) == value
