@@ -15,11 +15,19 @@ def would_update_comment(hub, resource_type: str, name: str) -> str:
 
 
 def no_resource_delete_comment(hub, resource_type: str) -> str:
-    return f"Delete operation for resource type {resource_type} is not supported."
+    return (
+        f"No-Op: Delete operation for resource type {resource_type} is not supported."
+    )
 
 
 def no_resource_create_update_comment(hub, resource_type: str) -> str:
-    return f"Create and update operations for resource type {resource_type} are not supported."
+    return f"No-Op: Create and update operations for resource type {resource_type} are not supported."
+
+
+def no_resource_update_comment(hub, resource_type: str) -> str:
+    return (
+        f"No-Op: Update operation for resource type {resource_type} is not supported."
+    )
 
 
 def delete_comment(hub, resource_type: str, name: str) -> str:
