@@ -337,10 +337,14 @@ def find_native_resource_type(hub, resource_type: str) -> str:
         for part in res_type.split("."):
             hub_ref = hub_ref[part]
         try:
-            return hub_ref["NATIVE_RESOURCE_TYPE"]
+            ret = hub_ref["NATIVE_RESOURCE_TYPE"]
         except AttributeError:
-            return res_type
+            hub.log.warning(f"Can't find native resource type for {resource_type}")
+            ret = res_type
 
-    return _GCP_RESOURCE_TYPES_CACHE.get(
-        resource_type, fetch_res_type_mapping(resource_type)
+        _GCP_RESOURCE_TYPES_CACHE[res_type] = ret
+        return ret
+
+    return _GCP_RESOURCE_TYPES_CACHE.get(resource_type) or fetch_res_type_mapping(
+        resource_type
     )
