@@ -110,7 +110,6 @@ def get_non_updatable_properties(hub, resource_type: str) -> Set:
 def get_changed_non_updatable_properties(
     hub, resource_type: str, changes: DeepDiff
 ) -> Set:
-
     if not changes:
         return set()
 
@@ -137,10 +136,8 @@ def get_changed_non_updatable_properties(
                     changed_property_path_elements[i].strip("'")
                 )
         formatted_property_path = "".join(formatted_path_elements)
-        for non_updatable_property_path in non_updatable_properties:
-            if non_updatable_property_path == formatted_property_path:
-                changed_non_updatable_properties.add(non_updatable_property_path)
-                break
+        if formatted_property_path in non_updatable_properties:
+            changed_non_updatable_properties.add(formatted_property_path)
 
     return changed_non_updatable_properties
 
